Codable

Derive Macro Codable 

#[derive(Codable)]
{
    // Attributes available to this derive:
    #[encode]
    #[uencode]
    #[kencode]
}
Check that the derive is being implemented on a basic enum without any contents on the variants. Then verify that there are code attributes on each Variant. From there assign each encode, decode mapping corresponding to the prior scan’s results.