A proc-macro for automatically generating encoding/decoding functions.
Derive Macros
- Codable
- Check that the derive is being implemented on a basic enum without any contents on the variants. Then verify that there are code attributes on each Variant. From there assign each encode, decode mapping corresponding to the prior scan’s results.